@@ -15,7 +15,7 @@ from .expression import Expression
 
 @dataclass(frozen=True, kw_only=True, repr=False)
 class Literal(Expression):
-    body: dict[str, Expression] | list[Expression] | str | float | int | bool | None
+    body: dict[str, Expression] | list['Literal | str | float | int | bool | None'] | str | float | int | bool | None
 
     def eval(self, entity_type: type[Entity], variables: dict[str, Selectable]) -> sql.atoms.literal.Literal:
         body = self.body
@@ -31,7 +31,7 @@ class Literal(Expression):
             type_ = str
         elif isinstance(body, list):
             type_ = list
-            body = [v.eval(entity_type, variables).value for v in body]
+            body = [v.eval(entity_type, variables).value if isinstance(v, Literal) else v for v in body]
         else:
             raise TypeError(f"Unsupported literal type: {type(body)}")
         return sql.atoms.literal.Literal(type_=type_, value=body)
